@@ -3,16 +3,11 @@ from datetime import datetime
 from typing import TYPE_CHECKING, Iterator, List, Optional, Sequence
 
 from boto3.dynamodb.types import TypeDeserializer
-from pypgstac.db import PgstacDB
 
-from .dependencies import get_settings, get_table
+from .config import settings
+from .dependencies import get_table
 from .schemas import Ingestion, Status
-from .utils import (
-    IngestionType,
-    convert_decimals_to_float,
-    get_db_credentials,
-    load_into_pgstac,
-)
+from .utils import get_db_credentials, load_items
 
 if TYPE_CHECKING:
     from aws_lambda_typing import context as context_
@@ -43,7 +38,7 @@ def update_dynamodb(
     """
     # Update records in DynamoDB
     print(f"Updating ingested items status in DynamoDB, marking as {status}...")
-    table = get_table(get_settings())
+    table = get_table(settings)
     with table.batch_writer(overwrite_by_pkeys=["created_by", "id"]) as batch:
         for ingestion in ingestions:
             batch.put_item(
@@ -64,24 +59,14 @@ def handler(event: "events.DynamoDBStreamEvent", context: "context_.Context"):
         print("No queued ingestions to process")
         return
 
-    items = [
-        # NOTE: Important to deserialize values to convert decimals to floats
-        convert_decimals_to_float(ingestion.item)
-        for ingestion in ingestions
-    ]
-
-    creds = get_db_credentials(os.environ["DB_SECRET_ARN"])
-
     # Insert into PgSTAC DB
     outcome = Status.succeeded
     message = None
     try:
-        with PgstacDB(dsn=creds.dsn_string, debug=True) as db:
-            load_into_pgstac(
-                db=db,
-                ingestions=items,
-                table=IngestionType.items,
-            )
+        load_items(
+            creds=get_db_credentials(os.environ["DB_SECRET_ARN"]),
+            ingestions=ingestions,
+        )
     except Exception as e:
         print(f"Encountered failure loading items into pgSTAC: {e}")
         outcome = Status.failed
